PyPOM
=====

PyPOM is a Python Page Object Model library for Selenium and Splinter tests.

.. image:: https://img.shields.io/badge/license-MPL%202.0-blue.svg
   :target: https://github.com/KeshavaReddy1101/PyPOM/blob/master/LICENSE.txt
   :alt: License
.. image:: https://img.shields.io/pypi/v/PyPOM.svg
   :target: https://pypi.python.org/pypi/PyPOM/
   :alt: PyPI
.. image:: https://img.shields.io/travis/mozilla/PyPOM.svg
   :target: https://travis-ci.org/mozilla/PyPOM/
   :alt: Travis
.. image:: https://img.shields.io/coveralls/mozilla/PyPOM.svg
   :target: https://coveralls.io/github/mozilla/PyPOM
   :alt: Coverage
.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg
   :target: http://pypom.readthedocs.io/en/latest/
   :alt: Read the Docs
.. image:: https://img.shields.io/github/issues-raw/mozilla/PyPOM.svg
   :target: https://github.com/KeshavaReddy1101/PyPOM/issues
   :alt: Issues
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black

Resources
---------

- `Documentation <http://pypom.readthedocs.io/>`_
- `Issue Tracker <https://github.com/KeshavaReddy1101/PyPOM/issues>`_
- `Code <https://github.com/KeshavaReddy1101/PyPOM>`_
